##############################################################################
#
# Copyright (c) 2004 Zope Foundation and Contributors.
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################
"""test resolution of dotted names
"""
import unittest


class Test_resolve(unittest.TestCase):

    def _callFUT(self, *args, **kw):
        from zope.dottedname.resolve import resolve
        return resolve(*args, **kw)

    def test_no_dots_non_importable(self):
        self.assertRaises(ImportError,
                          self._callFUT, '_non_importable_module_')

    def test_no_dots(self):
        self.assertTrue(self._callFUT('unittest') is unittest)

    def test_module_attr_nonesuch(self):
        self.assertRaises(ImportError, self._callFUT, 'unittest.nonesuch')

    def test_module_attr(self):
        self.assertTrue(
            self._callFUT('unittest.TestCase') is unittest.TestCase)

    def test_submodule(self):
        from zope import dottedname
        self.assertTrue(
            self._callFUT('zope.dottedname') is dottedname)

    def test_submodule_not_yet_imported(self):
        import sys

        import zope.dottedname
        try:
            del sys.modules['zope.dottedname.example']
        except KeyError:
            pass
        try:
            del zope.dottedname.example
        except AttributeError:
            pass
        found = self._callFUT('zope.dottedname.example')
        self.assertTrue(found is sys.modules['zope.dottedname.example'])

    def test_submodule_attr(self):
        from zope.dottedname.resolve import resolve
        self.assertTrue(
            self._callFUT('zope.dottedname.resolve.resolve') is resolve)

    def test_relative_no_module(self):
        self.assertRaises(ValueError, self._callFUT, '.resolve')

    def test_relative_w_module(self):
        from zope.dottedname.resolve import resolve
        self.assertTrue(
            self._callFUT('.resolve.resolve', 'zope.dottedname') is resolve)

    def test_relative_w_module_multiple_dots(self):
        from zope.dottedname import resolve
        self.assertTrue(
            self._callFUT('..resolve', 'zope.dottedname.tests') is resolve)


def test_suite():
    return unittest.TestSuite((
        unittest.defaultTestLoader.loadTestsFromTestCase(Test_resolve),
    ))



##############################################################################
#
# Copyright (c) 2007 Zope Foundation and Contributors.
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################
# This package is developed by the Zope Toolkit project, documented here:
# https://zopetoolkit.readthedocs.io/
# When developing and releasing this package, please follow the documented
# Zope Toolkit policies as described by this documentation.
##############################################################################
import os

from setuptools import find_packages
from setuptools import setup


def read(*rnames):
    with open(os.path.join(os.path.dirname(__file__), *rnames)) as f:
        return f.read()


setup(name="zope.dottedname",
      version='6.0',
      author='Zope Foundation and Contributors',
      author_email='zope-dev@zope.dev',
      description='Resolver for Python dotted names.',
      long_description='\n\n'.join((
          read('README.rst'),
          read('CHANGES.rst'),
      )),
      keywords='resolve dotted name',
      classifiers=[
          'Development Status :: 5 - Production/Stable',
          'Environment :: Web Environment',
          'Intended Audience :: Developers',
          'License :: OSI Approved :: Zope Public License',
          'Programming Language :: Python',
          'Programming Language :: Python :: 3',
          'Programming Language :: Python :: 3.7',
          'Programming Language :: Python :: 3.8',
          'Programming Language :: Python :: 3.9',
          'Programming Language :: Python :: 3.10',
          'Programming Language :: Python :: 3.11',
          'Programming Language :: Python :: Implementation :: CPython',
          'Programming Language :: Python :: Implementation :: PyPy',
          'Natural Language :: English',
          'Operating System :: OS Independent',
          'Topic :: Internet :: WWW/HTTP',
          'Framework :: Zope :: 3',
      ],
      url='https://github.com/zopefoundation/zope.dottedname',
      license='ZPL 2.1',
      packages=find_packages('src'),
      package_dir={'': 'src'},
      namespace_packages=['zope'],
      python_requires='>=3.7',
      install_requires=['setuptools'],
      extras_require={
          'testing': [],
          'docs': [
              'Sphinx',
          ]
      },
      tests_require=[],
      test_suite='zope.dottedname.tests.test_suite',
      include_package_data=True,
      zip_safe=False
      )
